@@ -147,10 +147,17 @@ class PlatoClient(object):
         for (src, dist) in edges:
             src_idx = vertexes_map.get(vertex_types[0]).get(src)    # 注意df中src的指的类型
             if src_idx is None:
+                logger.error("边数据替换报错: src:{}   src_type:{}     vertexes_map:{}     vertex_types:{}".format(
+                    src, type(src), vertexes_map, vertex_types
+                ))
                 raise PlatoException("边数据替换报错：起点{}找不到对应的下标".format(src))
+
             dist_idx = vertexes_map.get(vertex_types[0]).get(dist) if len(vertex_types) == 1 else\
                                            vertexes_map.get(vertex_types[1]).get(dist)
             if dist_idx is None:
+                logger.error("边数据替换报错: dist:{}   dist_type:{}     vertexes_map:{}     vertex_types:{}".format(
+                    dist, type(dist), vertexes_map, vertex_types
+                ))
                 raise PlatoException("边数据替换报错：终点{}找不到对应的下标".format(dist))
 
             data.append([src_idx, dist_idx])
